import request from '@/utils/request'

// 初始化项目
export function initProject() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_项目名称_查询数据'
    }
  })
}
// 机床查询
export function searchmachine(check, num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_机床名称_查询数据',
      param: '项目流水号_check=' + check + '&项目流水号=' + num
    }
  })
}
// 分组查询
export function searchTeam(machineNumber) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_组件名称_查询数据',
      param: '机床流水号=' + machineNumber
    }
  })
}
// 初始化物料
export function searchPart() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_离线外购件_出库查询'
    }
  })
}
// 人员查询 需要在部门确定之后修改
export function searchPeople(data1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_人员查询_库存部门',
      param: '角色编号=' + data1
    }
  })
}
// 离线件出库
export function outlinePartOut(data1, data2, data3, data4, data5, data6, data7, data8, data9, data10) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_离线采购件_零件出库',
      param: '离线合同明细流水号=' + data1 + '&领用者=' + data2 + '&出库数量=' + data3 + '&货位流水号=' + data4 + '&备注=' + data5 + '&项目流水号=' + data6 + '&机床流水号=' + data7 + '&组件流水号=' + data8 + '&物料流水号=' + data9 + '&出库人员流水号=' + data10
    }
  })
}
// 查询出库记录
export function outRecord(data1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_离线外购件出库_出库记录',
      param: '离线合同明细流水号=' + data1
    }
  })
}
